@@ -35,7 +35,7 @@ config = {
         'dev', 'info', 'api', 'status', 'login', 'frontpage'],
     'cookie_age': '2592000',  # 1 month
     'server_store': ['tiddlywebplugins.tiddlyspace.store', {
-        'db_config': 'mysql:///tiddlyspace?charset=utf8&use_unicode=0'}],
+        'db_config': 'mysql:///tiddlyspace?charset=utf8mb4'}],
     'tiddlywebwiki.binary_limit': 1048576,  # 1 MB
     # TiddlyWiki external, alpha, beta serialization
     'base_tiddlywiki_beta': TIDDLYWIKI_BETA,
